@@ -5,15 +5,15 @@ import (
 	"bytes"
 	"fmt"
 	"io/fs"
-
-	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
+	"maps"
+	"slices"
 )
 
 // NewTar returns the bytes of a new tar archive containing root.
 func NewTar(root map[string]any) ([]byte, error) {
 	buffer := &bytes.Buffer{}
 	tarWriter := tar.NewWriter(buffer)
-	for _, key := range chezmoimaps.SortedKeys(root) {
+	for _, key := range slices.Sorted(maps.Keys(root)) {
 		if err := tarAddEntry(tarWriter, key, root[key]); err != nil {
 			return nil, err
 		}
@@ -47,7 +47,7 @@ func tarAddEntry(w *tar.Writer, name string, entry any) error {
 		}); err != nil {
 			return err
 		}
-		for _, key := range chezmoimaps.SortedKeys(entry) {
+		for _, key := range slices.Sorted(maps.Keys(entry)) {
 			if err := tarAddEntry(w, name+"/"+key, entry[key]); err != nil {
 				return err
 			}
@@ -74,7 +74,7 @@ func tarAddEntry(w *tar.Writer, name string, entry any) error {
 		}); err != nil {
 			return err
 		}
-		for _, key := range chezmoimaps.SortedKeys(entry.Entries) {
+		for _, key := range slices.Sorted(maps.Keys(entry.Entries)) {
 			if err := tarAddEntry(w, name+"/"+key, entry.Entries[key]); err != nil {
 				return err
 			}
