@@ -2,6 +2,8 @@ package chezmoi
 
 import (
 	"os"
+	"runtime"
+	"strconv"
 	"testing"
 
 	"github.com/alecthomas/assert/v2"
@@ -60,3 +62,26 @@ func TestNewAbsPathFromExtPath(t *testing.T) {
 		})
 	}
 }
+
+func TestAbsPathJoin(t *testing.T) {
+	for i, tc := range []struct {
+		skip     bool
+		absPath  AbsPath
+		relPath  RelPath
+		expected AbsPath
+	}{
+		{
+			skip:     runtime.GOOS != "windows",
+			absPath:  NewAbsPath("//WSL.LOCALHOST/UBUNTU/home/user"),
+			relPath:  NewRelPath(".local/share/chezmoi"),
+			expected: NewAbsPath("//WSL.LOCALHOST/UBUNTU/home/user/.local/share/chezmoi"),
+		},
+	} {
+		t.Run(strconv.Itoa(i), func(t *testing.T) {
+			if tc.skip {
+				t.Skip()
+			}
+			assert.Equal(t, tc.expected, tc.absPath.Join(tc.relPath))
+		})
+	}
+}
