@@ -8,7 +8,7 @@ import (
 	"filippo.io/age"
 	"github.com/alecthomas/assert/v2"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
+	"github.com/twpayne/chezmoi/internal/chezmoitest"
 )
 
 var ageCommands = []string{
