@@ -25,6 +25,7 @@ type ExternalDiffSystem struct {
 	destDirAbsPath AbsPath
 	tempDirAbsPath AbsPath
 	filter         *EntryTypeFilter
+	pagerCmdFunc   func() (*exec.Cmd, error)
 	reverse        bool
 	scriptContents bool
 	textConvFunc   TextConvFunc
@@ -44,6 +45,7 @@ func NewExternalDiffSystem(
 	command string,
 	args []string,
 	destDirAbsPath AbsPath,
+	pagerCmdFunc func() (*exec.Cmd, error),
 	options *ExternalDiffSystemOptions,
 ) *ExternalDiffSystem {
 	return &ExternalDiffSystem{
@@ -52,6 +54,7 @@ func NewExternalDiffSystem(
 		args:           args,
 		destDirAbsPath: destDirAbsPath,
 		filter:         options.Filter,
+		pagerCmdFunc:   pagerCmdFunc,
 		reverse:        options.Reverse,
 		scriptContents: options.ScriptContents,
 		textConvFunc:   options.TextConvFunc,
@@ -111,7 +114,7 @@ func (s *ExternalDiffSystem) Mkdir(name AbsPath, perm fs.FileMode) error {
 		if err := os.MkdirAll(targetAbsPath.String(), perm); err != nil {
 			return err
 		}
-		if err := s.runDiffCommand(devNullAbsPath, targetAbsPath); err != nil {
+		if err := s.RunDiffCommand(devNullAbsPath, targetAbsPath); err != nil {
 			return err
 		}
 	}
@@ -147,7 +150,7 @@ func (s *ExternalDiffSystem) Remove(name AbsPath) error {
 		case err != nil:
 			return err
 		case s.filter.IncludeFileInfo(fileInfo):
-			if err := s.runDiffCommand(name, devNullAbsPath); err != nil {
+			if err := s.RunDiffCommand(name, devNullAbsPath); err != nil {
 				return err
 			}
 		}
@@ -164,7 +167,7 @@ func (s *ExternalDiffSystem) RemoveAll(name AbsPath) error {
 		case err != nil:
 			return err
 		case s.filter.IncludeFileInfo(fileInfo):
-			if err := s.runDiffCommand(name, devNullAbsPath); err != nil {
+			if err := s.RunDiffCommand(name, devNullAbsPath); err != nil {
 				return err
 			}
 		}
@@ -183,6 +186,101 @@ func (s *ExternalDiffSystem) RunCmd(cmd *exec.Cmd) error {
 	return s.system.RunCmd(cmd)
 }
 
+// RunDiffCommand runs the external diff command.
+func (s *ExternalDiffSystem) RunDiffCommand(destAbsPath, targetAbsPath AbsPath) error {
+	templateData := struct {
+		Destination string
+		Target      string
+	}{
+		Destination: destAbsPath.String(),
+		Target:      targetAbsPath.String(),
+	}
+
+	if s.reverse {
+		templateData.Destination, templateData.Target = templateData.Target, templateData.Destination
+	}
+
+	args := make([]string, 0, len(s.args))
+	// Work around a regression introduced in 2.1.5
+	// (https://github.com/twpayne/chezmoi/pull/1328) in a user-friendly way.
+	//
+	// Prior to #1328, the diff.args config option was prepended to the default
+	// order of files to the diff command. Post #1328, the diff.args config
+	// option replaced all arguments to the diff command.
+	//
+	// Work around this by looking for any templates in diff.args. An arg is
+	// considered a template if, after execution as a template, it is not equal
+	// to the original arg.
+	anyTemplateArgs := false
+	for i, arg := range s.args {
+		tmpl, err := template.New("diff.args[" + strconv.Itoa(i) + "]").Parse(arg)
+		if err != nil {
+			return err
+		}
+
+		builder := strings.Builder{}
+		if err := tmpl.Execute(&builder, templateData); err != nil {
+			return err
+		}
+		args = append(args, builder.String())
+
+		// Detect template arguments.
+		if arg != builder.String() {
+			anyTemplateArgs = true
+		}
+	}
+
+	// If there are no template arguments, then append the destination and
+	// target paths as prior to #1328.
+	if !anyTemplateArgs {
+		args = append(args, templateData.Destination, templateData.Target)
+	}
+
+	diffCmd := exec.Command(s.command, args...)
+	diffCmd.Stdin = os.Stdin
+	diffCmd.Stderr = os.Stderr
+	var diffCmdErr error
+	switch diffPagerCmd, err := s.pagerCmdFunc(); {
+	case err != nil:
+		return err
+	case diffPagerCmd == nil:
+		diffCmd.Stdout = os.Stdout
+		diffCmdErr = chezmoilog.LogCmdRun(slog.Default(), diffCmd)
+	default:
+		reader, writer, err := os.Pipe()
+		if err != nil {
+			return err
+		}
+		defer writer.Close()
+		diffPagerCmd.Stdin = reader
+		if err := chezmoilog.LogCmdStart(slog.Default(), diffPagerCmd); err != nil {
+			return err
+		}
+		diffCmd.Stdout = writer
+		diffCmdErr = chezmoilog.LogCmdRun(slog.Default(), diffCmd)
+		if err := writer.Close(); err != nil {
+			return err
+		}
+		if err := diffPagerCmd.Wait(); err != nil {
+			return err
+		}
+	}
+
+	// Swallow exit status 1 errors if the entries differ and there are actual
+	// differences between the entries as diff commands traditionally exit with
+	// code 1 in this case.
+	if exitError := (&exec.ExitError{}); errors.As(diffCmdErr, &exitError) && exitError.ExitCode() == 1 {
+		switch entriesDiffer, err := s.entriesDiffer(destAbsPath, targetAbsPath); {
+		case err != nil:
+			return err
+		case entriesDiffer:
+			return nil
+		}
+	}
+
+	return diffCmdErr
+}
+
 // RunScript implements System.RunScript.
 func (s *ExternalDiffSystem) RunScript(scriptName RelPath, dir AbsPath, data []byte, options RunScriptOptions) error {
 	bits := EntryTypeScripts
@@ -205,7 +303,7 @@ func (s *ExternalDiffSystem) RunScript(scriptName RelPath, dir AbsPath, data []b
 		if err := os.WriteFile(targetAbsPath.String(), toData, 0o700); err != nil {
 			return err
 		}
-		if err := s.runDiffCommand(devNullAbsPath, targetAbsPath); err != nil {
+		if err := s.RunDiffCommand(devNullAbsPath, targetAbsPath); err != nil {
 			return err
 		}
 	}
@@ -286,7 +384,7 @@ func (s *ExternalDiffSystem) WriteFile(filename AbsPath, data []byte, perm fs.Fi
 		}
 
 		// Run the external diff command.
-		if err := s.runDiffCommand(fromAbsPath, toAbsPath); err != nil {
+		if err := s.RunDiffCommand(fromAbsPath, toAbsPath); err != nil {
 			return err
 		}
 	}
@@ -361,74 +459,3 @@ func (s *ExternalDiffSystem) entriesDiffer(absPath1, absPath2 AbsPath) (bool, er
 		return true, nil
 	}
 }
-
-// runDiffCommand runs the external diff command.
-func (s *ExternalDiffSystem) runDiffCommand(destAbsPath, targetAbsPath AbsPath) error {
-	templateData := struct {
-		Destination string
-		Target      string
-	}{
-		Destination: destAbsPath.String(),
-		Target:      targetAbsPath.String(),
-	}
-
-	if s.reverse {
-		templateData.Destination, templateData.Target = templateData.Target, templateData.Destination
-	}
-
-	args := make([]string, 0, len(s.args))
-	// Work around a regression introduced in 2.1.5
-	// (https://github.com/twpayne/chezmoi/pull/1328) in a user-friendly way.
-	//
-	// Prior to #1328, the diff.args config option was prepended to the default
-	// order of files to the diff command. Post #1328, the diff.args config
-	// option replaced all arguments to the diff command.
-	//
-	// Work around this by looking for any templates in diff.args. An arg is
-	// considered a template if, after execution as a template, it is not equal
-	// to the original arg.
-	anyTemplateArgs := false
-	for i, arg := range s.args {
-		tmpl, err := template.New("diff.args[" + strconv.Itoa(i) + "]").Parse(arg)
-		if err != nil {
-			return err
-		}
-
-		builder := strings.Builder{}
-		if err := tmpl.Execute(&builder, templateData); err != nil {
-			return err
-		}
-		args = append(args, builder.String())
-
-		// Detect template arguments.
-		if arg != builder.String() {
-			anyTemplateArgs = true
-		}
-	}
-
-	// If there are no template arguments, then append the destination and
-	// target paths as prior to #1328.
-	if !anyTemplateArgs {
-		args = append(args, templateData.Destination, templateData.Target)
-	}
-
-	cmd := exec.Command(s.command, args...)
-	cmd.Stdin = os.Stdin
-	cmd.Stdout = os.Stdout
-	cmd.Stderr = os.Stderr
-	err := chezmoilog.LogCmdRun(slog.Default(), cmd)
-
-	// Swallow exit status 1 errors if the entries differ and there are actual
-	// differences between the entries as diff commands traditionally exit with
-	// code 1 in this case.
-	if exitError := (&exec.ExitError{}); errors.As(err, &exitError) && exitError.ExitCode() == 1 {
-		switch entriesDiffer, err := s.entriesDiffer(destAbsPath, targetAbsPath); {
-		case err != nil:
-			return err
-		case entriesDiffer:
-			return nil
-		}
-	}
-
-	return err
-}
