@@ -13,7 +13,7 @@ import (
 	"github.com/twpayne/go-vfs/v5"
 	"github.com/twpayne/go-vfs/v5/vfst"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
+	"github.com/twpayne/chezmoi/internal/chezmoitest"
 )
 
 func TestApplyCmd(t *testing.T) {
@@ -241,7 +241,7 @@ func TestUserAgent(t *testing.T) {
 }
 
 func TestIssue2132(t *testing.T) {
-	chezmoitest.WithTestFS(t, map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
 		"/home/user/.local/share/chezmoi/remove_dot_dir/non_existent_file": "",
 	}, func(fileSystem vfs.FS) {
 		config1 := newTestConfig(t, fileSystem)
