@@ -7,9 +7,9 @@ import (
 	"strings"
 	"time"
 
-	"github.com/google/go-github/v69/github"
+	"github.com/google/go-github/v61/github"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 type gitHubConfig struct {
@@ -368,8 +368,9 @@ func (c *Config) getGitHubClient(ctx context.Context) (*github.Client, error) {
 	return c.gitHub.client, nil
 }
 
-func gitHubSplitOwnerRepo(ownerRepo string) (string, string, error) {
-	owner, repo, ok := strings.Cut(ownerRepo, "/")
+func gitHubSplitOwnerRepo(ownerRepo string) (owner, repo string, err error) {
+	var ok bool
+	owner, repo, ok = strings.Cut(ownerRepo, "/")
 	if !ok {
 		return "", "", fmt.Errorf("%s: not an owner/repo", ownerRepo)
 	}
